@@ -1,10 +1,10 @@
 #!/bin/bash
 
-VERSION="1.0.5"
+VERSION="1.0.7"
 MILESTONE=
 RPM_RELEASE="1"
 
-ROLE_NAME="ovirt.hosted-engine-setup"
+ROLE_NAME="ovirt.hosted_engine_setup"
 PACKAGE_NAME="ovirt-ansible-hosted-engine-setup"
 PREFIX=/usr/local
 DATAROOT_DIR=$PREFIX/share
@@ -12,7 +12,7 @@ ROLES_DATAROOT_DIR=$DATAROOT_DIR/ansible/roles
 DOC_DIR=$DATAROOT_DIR/doc
 PKG_DATA_DIR=${PKG_DATA_DIR:-$ROLES_DATAROOT_DIR/$PACKAGE_NAME}
 PKG_DOC_DIR=${PKG_DOC_DIR:-$DOC_DIR/$PACKAGE_NAME}
-ROLENAME_LEGACY="${ROLENAME_LEGACY:-$ROLES_DATAROOT_DIR/ovirt-hosted-engine-setup}"
+ROLENAME_LEGACY="${ROLENAME_LEGACY:-$ROLES_DATAROOT_DIR/ovirt.hosted-engine-setup}"
 ROLENAME_LEGACY_UPPERCASE="${ROLENAME_LEGACY_UPPERCASE:-$ROLES_DATAROOT_DIR/oVirt.hosted-engine-setup}"
 
 RPM_VERSION=$VERSION
